@@ -1,5 +1,5 @@
 """
-SQLObject 0.12.2
+SQLObject 0.12.3
 ----------------
 
 :author: Ian Bicking <ianb@colorstudy.com>
@@ -920,7 +920,8 @@ class SQLObject(object):
         # If no connection was given, we'll inherit the class
         # instance variable which should have a _connection
         # attribute.
-        if (connection is not None) and (self._connection is not connection):
+        if (connection is not None) and \
+                (getattr(self, '_connection', None) is not connection):
             self._connection = connection
             # Sometimes we need to know if this instance is
             # global or tied to a particular connection.
@@ -1207,7 +1208,7 @@ class SQLObject(object):
             # Pass the connection object along if we were given one.
             if kw.has_key('connection'):
                 connection = kw.pop('connection')
-                if self._connection is not connection:
+                if getattr(self, '_connection', None) is not connection:
                     self._connection = connection
                     self.sqlmeta._perConnection = True
 
